@@ -21,7 +21,7 @@
 
 /* one arg */
 
-#define SAVEt_GP_ALIASED_SV	4
+/*** SPARE      	        4 ***/
 #define SAVEt_BOOL		5
 #define SAVEt_COMPILE_WARNINGS	6
 #define SAVEt_COMPPAD		7
@@ -341,11 +341,5 @@ STMT_START {                                 \
 #define save_op()		save_pushptr((void *)(PL_op), SAVEt_OP)
 
 /*
- * Local variables:
- * c-indentation-style: bsd
- * c-basic-offset: 4
- * indent-tabs-mode: nil
- * End:
- *
  * ex: set ts=8 sts=4 sw=4 et:
  */
